<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2013 IMIA net based solutions (d.frerich@imia.de)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

namespace IMIA\Base\Xclass\Rsaauth\Backend;

/**
 * rsaauth patch for multiple felogin-forms
 * http://forge.typo3.org/issues/24877
 *
 * @package     imia_base
 * @subpackage  Xclass
 * @author      David Frerich <d.frerich@imia.de>
 */
class CommandLineBackend extends \TYPO3\CMS\Rsaauth\Backend\CommandLineBackend
{
	/**
	 * @return \TYPO3\CMS\Rsaauth\Keypair A new key pair or NULL in case of error
	 * @see tx_rsaauth_abstract_backend::createNewKeyPair()
	 */
	public function getKeyPair()
    {
		$keyPair = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('TYPO3\\CMS\\Rsaauth\\Keypair');
		if (!$keyPair->isReady()) {
            // Create a temporary file. Security: tempnam() sets permissions to 0600
            $privateKeyFile = tempnam($this->temporaryDirectory, uniqid());
            // Generate the private key.
            //
            // PHP generates 1024 bit key files. We force command line version
            // to do the same and use the F4 (0x10001) exponent. This is the most
            // secure.
            $command = $this->opensslPath . ' genrsa -out ' . escapeshellarg($privateKeyFile) . ' 1024';
            \TYPO3\CMS\Core\Utility\CommandUtility::exec($command);
            // Test that we got a private key
            $privateKey = file_get_contents($privateKeyFile);
            if (FALSE !== strpos($privateKey, 'BEGIN RSA PRIVATE KEY')) {
                // Ok, we got the private key. Get the modulus.
                $command = $this->opensslPath . ' rsa -noout -modulus -in ' . escapeshellarg($privateKeyFile);
                $value = \TYPO3\CMS\Core\Utility\CommandUtility::exec($command);
                if (substr($value, 0, 8) === 'Modulus=') {
                    $publicKey = substr($value, 8);

                    $keyPair->setExponent(65537);
                    $keyPair->setPrivateKey($privateKey);
                    $keyPair->setPublicKey($publicKey);
                }
            } else {
                $keyPair = null;
            }
            @unlink($privateKeyFile);
        }

		return $keyPair;
	}
}