<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2013 IMIA net based solutions (d.frerich@imia.de)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

namespace IMIA\Base\Xclass\Rsaauth\Backend;

/**
 * rsaauth patch for multiple felogin-forms
 * http://forge.typo3.org/issues/24877
 *
 * @package     imia_base
 * @subpackage  Xclass
 * @author      David Frerich <d.frerich@imia.de>
 */
class PhpBackend extends \TYPO3\CMS\Rsaauth\Backend\PhpBackend
{
	/**
	 * Creates a new or gets an existing public/private key pair using PHP OpenSSL extension.
	 *
	 * @return \TYPO3\CMS\Rsaauth\Keypair|NULL A new key pair or NULL in case of error
	 * @see tx_rsaauth_abstract_backend::createNewKeyPair()
	 */
	public function getKeyPair()
    {
		$keyPair = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('TYPO3\\CMS\\Rsaauth\\Keypair');

        if (!$keyPair->isReady()) {
            $privateKey = @openssl_pkey_new();
            if ($privateKey) {
                // Create private key as string
                $privateKeyStr = '';
                openssl_pkey_export($privateKey, $privateKeyStr);
                // Prepare public key information
                $exportedData = '';
                $csr = openssl_csr_new(array(), $privateKey);
                openssl_csr_export($csr, $exportedData, FALSE);
                // Get public key (in fact modulus) and exponent
                $publicKey = $this->extractPublicKeyModulus($exportedData);
                $exponent = $this->extractExponent($exportedData);

                $keyPair->setExponent($exponent);
                $keyPair->setPrivateKey($privateKeyStr);
                $keyPair->setPublicKey($publicKey);
                // Clean up all resources
                openssl_free_key($privateKey);
            } else {
                $keyPair = null;
            }
        }

		return $keyPair;
	}
}