<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2013 IMIA net based solutions (d.frerich@imia.de)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

namespace IMIA\Base\Xclass\Rsaauth;

/**
 * rsaauth patch for multiple felogin-forms
 * http://forge.typo3.org/issues/24877
 *
 * @package     imia_base
 * @subpackage  Xclass
 * @author      David Frerich <d.frerich@imia.de>
 */
class Keypair extends \TYPO3\CMS\Rsaauth\Keypair implements \TYPO3\CMS\Core\SingletonInterface
{
    public function isReady()
    {
        return ($this->privateKey !== '' && $this->publicKeyModulus !== '');
    }

	/**
	 * Sets the private key
	 *
	 * @param string $privateKey The new private key
	 * @return void
	 */
	public function setExponent($exponent)
    {
        if ($this->isReady()) {
            throw new BadMethodCallException('setExponent() must not be called more than one time.', 1296062830);
        }

		$this->exponent = $exponent;
	}

	/**
	 * Sets the private key
	 *
	 * @param string $privateKey The new private key
	 * @return void
	 */
	public function setPrivateKey($privateKey)
    {
        if ($this->isReady()) {
            throw new BadMethodCallException('setPrivateKey() must not be called more than one time.', 1296062831);
        }

		$this->privateKey = $privateKey;
	}

	/**
	 * Sets the public key modulus
	 *
	 * @param string $publicKeyModulus The new public key modulus
	 * @return void
	 */
	public function setPublicKey($publicKeyModulus)
    {
        if ($this->isReady()) {
            throw new BadMethodCallException('setPublicKey() must not be called more than one time.', 1296062832);
        }

		$this->publicKeyModulus = $publicKeyModulus;
	}
}